


---

# octave_nexus
Foam can interact with Aptos with offline bling  
like a "laptop", "desktop", etc.

---

## Rules (License) 
This program is a mix.

octave_nexus/Rules.E.HTML

---

## Creation
```
pip install octave_nexus
```

## Greeting at a new habitat
```
octave_nexus build
octave_nexus demux_hap build_unverified_certificates
octave_nexus ventures on
```

The nexus is at:
[http://localhost:22000](http://localhost:22000)

******



## Parrot
### Equalize
To make 2 directories equal:
```
octave_nexus parrot equalize --origin "/media/lodge/safe_1/estate" --to "/media/lodge/safe_2/estate"
```

### Check Equality
This checks if the directories are equal.
```
octave_nexus parrot check_EQ --origin "/media/lodge/safe_1/estate" --to "/media/lodge/safe_2/estate"
```